var masterSettings = resources.Settings.shared;
var bodyFamily = masterSettings.get( "dungeonquest-body" );
var titleFamily = masterSettings.get( "dungeonquest-title" );
var numberFamily = masterSettings.get( "dungeonquest-number" );

function createBodyBox( sheet ) {
	var box = markupBox( sheet );
	
	box.defaultStyle = new TextStyle(
		FAMILY, bodyFamily,
		SIZE,   7,
		WEIGHT, WEIGHT_REGULAR
	);
	
	box.alignment = box.LAYOUT_CENTER;
	box.headlineAlignment = box.LAYOUT_CENTER;
	box.textFitting= box.FIT_SCALE_TEXT;
	
	return box;
}

function createTitleBox( sheet, useTitleFamily, size ) {
	var box = markupBox( sheet );
	
	box.defaultStyle = new TextStyle(
		FAMILY, useTitleFamily ? titleFamily : bodyFamily,
		SIZE,   size
	);

	box.alignment = box.LAYOUT_CENTER | box.LAYOUT_MIDDLE;
	box.headlineAlignment = box.LAYOUT_CENTER;
	
	box.lineTightness = 4;
	box.textFitting = box.FIT_SCALE_TEXT;
	
	return box;
}

function createNumberBox( sheet ) {
	var box = markupBox( sheet );
	
	box.defaultStyle = new TextStyle(
		FAMILY, numberFamily,
		SIZE,   15,
		WEIGHT, WEIGHT_REGULAR
	);
	
	box.alignment = box.LAYOUT_CENTER| box.LAYOUT_MIDDLE;
	box.headlineAlignment = box.LAYOUT_CENTER;	
	box.textFitting= box.FIT_SCALE_TEXT;
	
	return box;
}

var MACROS = '<define ap "<b>Any Phase:</b>">'
           + '<define al "<b>All Phases:</b>">'
           + '<define bc "<b>Before Combat:</b>">'
           + '<define ra "<b>Ranged:</b>">'
           + '<define ml "<b>Melee:</b>">'
           + '<define mg "<b>Magic:</b>">'
           + '<define rm "<b>Ranged and Melee:</b>">'
           + '<define mm "<b>Melee and Magic:</b>">'                    
           + '<define sk "<b>Skills:</b>">'
           + '<define rw "<b>Reward:</b>">'  
           + '<define fo "<b>Forage - </b>">'  
           + '<define ms "<b>Movement step:</b>">'            
           + '<define ss "<b>Story step:</b>">'           
           + '<define cq "Complete this Quest when you">'           
           + '<define cl "Climb +2">'   
           + '<define cl+ "Climb +4">' 
           + '<define di "Diplomacy +2">'   
           + '<define di+ "Diplomacy +4">'  
           + '<define en "Endure +2">'   
           + '<define en+ "Endure +4">' 
           + '<define hi "Hide +2">'   
           + '<define hi+ "Hide +4">'
           + '<define ju "Jump +2">'   
           + '<define ju+ "Jump +4">'   
           + '<define lo "Lore +2">'   
           + '<define lo+ "Lore +4">'  
           + '<define pr "Prophecy +2">'   
           + '<define pr+ "Prophecy +4">'           
           + '<define re "Resist +2">'   
           + '<define re+ "Resist +4">' 
           + '<define sn "Sneak +2">'   
           + '<define sn+ "Sneak +4">'  
           + '<define sp "Spot +2">'   
           + '<define sp+ "Spot +4">'            
           + '<define sw "Swim +2">' 
           + '<define sw+ "Swim +4">'
           + '<define sw- "Swim -4">'
           + '<define ti "Tinker +2">'   
           + '<define ti+ "Tinker +4">' 
           + '<define + "<size 10><b>@1;</b></size>">' 
           + '<define ++ "<size 14><b>@1;</b></size>">'  
 	       + '<define hr "<image res://dungeonquest/card-divider.png 60pt 3.5pt>">'  
 	       + '<define hs "<image res://dungeonquest/card-halfspace.png 60pt 2.5pt>">'   
           + '<define att "<image res://runebound/elements/icon-mind.png 6pt 9pt> <size 12>@1;<size 10>/<size 7>@2;     <image res://runebound/elements/icon-body.png 6.9pt 9pt> <size 12>@3;<size 10>/<size 7>@4;     <image res://runebound/elements/icon-spirit.png 9pt 9pt> <size 12>@5;<size 10>/<size 7>@6;      <image res://runebound/elements/icon-wounds.png 10.8pt 9pt> <size 12>@7;</size>">'                        
           + '<define min "<image res://runebound/elements/icon-mind.png 4.3pt 6.5pt center>">' 
           + '<define bod "<image res://runebound/elements/icon-body.png 5.0pt 6.5pt center>">' 
           + '<define spi "<image res://runebound/elements/icon-spirit.png 6.5pt 6.5pt center>">' 
           + '<define wou "<image res://runebound/elements/icon-wounds.png 7.8pt 6.5pt center>">'   
           + '<define exh "<image res://runebound/elements/icon-exhaustion.png 4.6pt 6.5pt center>">'        
           + '<define gol "<image res://runebound/elements/icon-gold.png 4.8pt 6.5pt center>">'   
           + '<define div "<image res://runebound/elements/icon-divinity.png 4.4pt 6.5pt center>">'
           + '<define epi "<image res://runebound/elements/icon-epic.png 5.3pt 6.5pt center>">'
           + '<define fig "<image res://runebound/elements/icon-fighting.png 7.0pt 6.5pt center>">'  
           + '<define fro "<image res://runebound/elements/icon-frost.png 7.5pt 6.5pt center>">'
           + '<define whi "<image res://runebound/elements/icon-white-death.png 4.1pt 6.5pt center>">'
           + '<define moo "<image res://runebound/elements/icon-moon.png 6.5pt 6.5pt center>">'  
           + '<define sku "<image res://runebound/elements/icon-skull.png 4.8pt 6.5pt center>">' 
           + '<define sun "<image res://runebound/elements/icon-sun.png 6.5pt 6.5pt center>">' 
           + '<define sub "<image res://runebound/elements/icon-subterfuge.png 11.7pt 6.5pt center>">'  
           + '<define sur "<image res://runebound/elements/icon-survival.png 4.8pt 6.5pt center>">' 
           + '<define wiz "<image res://runebound/elements/icon-wizardry.png 6.0pt 6.5pt center>">' 
           + '<define ttt "<image res://runebound/elements/icon-timing-text.png 12.2pt 6.5pt center>">' 
           + '<define tbc "<image res://runebound/elements/icon-timing-before-combat.png 10.1pt 6.5pt center>">' 
           + '<define tmo "<image res://runebound/elements/icon-timing-movement.png 5.1pt 6.5pt center>">'     
           + '<define men "<image res://runebound/elements/icon-menace.png 5.5pt 6.5pt center>">';      